@@ -312,7 +312,9 @@ def load_config_work_requirement() -> ConfigWorkRequirement:
             task_batch_size=task_batch_size,
             task_count=task_count,
             task_data=wr_section.get(TASK_DATA, None),
+            task_data_inputs=wr_section.get(TASK_DATA_INPUTS, None),
             task_data_file=wr_section.get(TASK_DATA_FILE, None),
+            task_data_outputs=wr_section.get(TASK_DATA_OUTPUTS, None),
             task_group_count=task_group_count,
             task_group_name=wr_section.get(TASK_GROUP_NAME, None),
             task_name=wr_section.get(TASK_NAME, None),
